@@ -1,6 +1,7 @@
 import unittest
 import waveletai
 import os
+import uuid
 from waveletai.app import App
 from waveletai.model import Model
 from waveletai.constants import Visibility
@@ -22,8 +23,9 @@ class AppTestCase(unittest.TestCase):
 
     def test_2_update_app(self):
         waveletai.set_app(app_id)
-        app: App = waveletai.update_app(name='zz_sdk', desc='sdk_update', tags=[])
-        self.assertEqual('sdk_update', app.desc)
+        name = "sdk-u-" + str(uuid.uuid4()).split("-")[0]
+        app: App = waveletai.update_app(name=name, desc='sdk_update', tags=[])
+        self.assertEqual(name, app.name)
 
     def test_3_create_model(self):
         waveletai.set_app(app_id)
