@@ -1,6 +1,7 @@
 import unittest
 import waveletai
 import os
+import uuid
 from waveletai.dataset import Dataset
 
 
@@ -51,10 +52,11 @@ class DataTestCase(unittest.TestCase):
 
     def test_6_update_dataset(self):
         waveletai.set_app(app_id)
+        name = "sdk-u-"+str(uuid.uuid4()).split("-")[0]
         dataset: Dataset = waveletai.get_dataset(dataset_id)
-        dataset.update(name="sdk-add-app-1", desc="sdk-add-app-desc-1")
+        dataset.update(name=name, desc="sdk-update-data-desc-1")
         dataset: Dataset = waveletai.get_dataset(dataset_id)
-        self.assertEqual("sdk-add-app-1", dataset.name)
+        self.assertEqual(name, dataset.name)
 
     def test_7_del_dataset(self):
         waveletai.set_app(app_id)
