@@ -1,5 +1,6 @@
 import unittest
 import waveletai
+import uuid
 from waveletai.model import Model, ModelVersion
 from waveletai.experiment import Experiment
 from waveletai.constants import Visibility, ModelSourceType
@@ -34,8 +35,9 @@ class ModelTestCase(unittest.TestCase):
     def test_03_update_model(self):
         waveletai.set_app(app_id)
         waveletai.set_model(model_id)
-        model: Model = waveletai.update_model(name='sdk_test_case', visibility='private', desc='123')
-        self.assertEqual("123", model.desc)
+        name = "sdk-u-" + str(uuid.uuid4()).split("-")[0]
+        model: Model = waveletai.update_model(name=name, visibility='private', desc='123')
+        self.assertEqual(name, model.name)
 
     def test_04_register_model_version(self):
         waveletai.set_app(app_id)
